# $Id: godi_tools.mk 530 2005-04-04 11:58:34Z gerd $
#
# This is an auxiliary Makefile used by programs of the
# godi-tools collection.
#
# Copyright 2004 by Gerd Stolpmann.
#
# This file is part of godi-tools.
#
# godi-tools is free software; you can redistribute it and/or modify it
# under the conditions in the file LICENSE.
#
# godi-tools is distributed WITHOUT ANY WARRANTY, as detailed in the
# file LICENSE.

.if exists(${.PARSEDIR}/bsd.pkg.mk)
.include "${.PARSEDIR}/bsd.pkg.mk"
.SILENT:
.else
# We need some bootstrapping...
_godi_confdir!= godi_confdir
.include "${_godi_confdir}/../build/mk/bsd.pkg.mk"
.endif

# Note: We include bsd.pkg.mk and not bsd.prefs.mk because FETCH_CMD etc.
# are defined in the first file. Of course, this should be changed.

BUILD_BASE := ${LOCALBASE}/build
BUILD_FILES := ${BUILD_BASE}/buildfiles

self := ${.PARSEDIR}/godi_tools.mk

# Initialize GODI_BUILD_SITES. We can always assume we know GODI_BUILD_SITE,
# as this is set by bootstrap. GODI_BUILD_SITES may be undef for old
# godi-core-mk versions.

GODI_BUILD_SITES ?= ${GODI_BUILD_SITE}

#----------------------------------------------------------------------
# Entry: get_sites
# Outputs the names of the GODI sites
#----------------------------------------------------------------------

.PHONY: get_sites

get_sites:
	@echo "${GODI_BUILD_SITES}"


#----------------------------------------------------------------------
# Entry: update_available
# The new "available.current" file is downloaded from the GODI server,
# and replaces the old instance.
# Required variables: target_dir, site
#----------------------------------------------------------------------

.PHONY: update_available

update_available:
	${ECHO} "===> Retrieving package list from ${site}..."
	cd ${target_dir} && \
	${FETCH_CMD} ${FETCH_BEFORE_ARGS} ${site}/available.new ${FETCH_AFTER_ARGS} && \
	${MV} available.new available.current

#----------------------------------------------------------------------
# Entry: install_build_instructions
# The build tgz for ${pkgname}-${version}${pkgrev} is downloaded from
# the GODI server ${site}, and replaces the previous build directory of the
# package.
# Required variables: site, pkgname, version, pkgrev
#----------------------------------------------------------------------

.PHONY: install_build_instructions update_defaults

.if make(install_build_instructions)
pkgrev ?= 0
.if ${pkgrev} == 0
pkgfullname := ${pkgname}-${version}
pkgfullversion := ${version}
.else
pkgfullname := ${pkgname}-${version}godi${pkgrev}
pkgfullversion := ${version}godi${pkgrev}
.endif
pkgsubdir := ${pkgname:C/-.*$//}
pkgdir := ${BUILD_BASE}/${pkgsubdir}
.endif

install_build_instructions:
	${ECHO} "===> Updating build instructions of ${pkgname} for version ${pkgfullversion}"
	${MKDIR} "${BUILD_FILES}"
	cd "${BUILD_FILES}" && \
	${FETCH_CMD} ${FETCH_BEFORE_ARGS} "${site}/${pkgfullname}.build.tgz" ${FETCH_AFTER_ARGS}
	${MKDIR} "${pkgdir}"
	cd "${pkgdir}" && ${RM} -rf "${pkgname}"
	cd "${pkgdir}" && ${GTAR} xzf "${BUILD_FILES}/${pkgfullname}.build.tgz" "${pkgname}"

# No longer used:

update_defaults:

#----------------------------------------------------------------------
# Entry: print-pkgtools-version
# Just outputs the contents of PKGTOOLS_VERSION which is normally set
# in bsd.prefs.mk
#----------------------------------------------------------------------

print-pkgtools-version:
	@${ECHO} ${PKGTOOLS_VERSION}
